@@ -3,7 +3,7 @@ package App::DualLivedList;
 use 5.005;
 use strict;
 
-our $VERSION = '0.00_10';
+our $VERSION = '0.01';
 
 1;
 __END__
@@ -74,19 +74,14 @@ which the dual-lived modules derives
 -u | --update    = installs or upgrades a module
 
 -v | --version   = App::DualLivedList version number 
-                   
-=head1 CAVEATS
-
-App::DualLivedList covers the latest stable perl
-which is 5.14.0
-
+                  
 =head1 AUTHOR
 
-Version 0.00_10 Kevin W. Henwood <Khen1950fx@aol.com>
+Version 0.01 Kevin W. Henwood <Khen1950fx@aol.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010, 2011 by Kevin W. Henwood
+Copyright (C) 2010-2012 by Kevin W. Henwood
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.5.0 or,
